@@ -161,7 +161,7 @@ def node_embedding_test_graph():
     edge_weight = pd.DataFrame({
         "@source_id": sources,
         "@target_id": targets,
-        "distance": weights
+        "weight": weights
     })
     frame.add_edge_properties(edge_weight, prop_type="numeric")
     return frame
@@ -245,7 +245,8 @@ def random_text_corpus():
     )
     return corpus
 
+
 @pytest.fixture(scope="session")
 def random_words():
-    corpus = list(random.sample(words.words(), 700))
+    corpus = list(set(random.sample(words.words(), 700)))
     return corpus
